@@ -33,11 +33,11 @@
 
 G_BEGIN_DECLS
 
-#define GALEON_SPINNER_TYPE		(galeon_spinner_get_type ())
-#define GALEON_SPINNER(obj)		(GTK_CHECK_CAST ((obj), GALEON_SPINNER_TYPE, GaleonSpinner))
-#define GALEON_SPINNER_CLASS(klass)	(GTK_CHECK_CLASS_CAST ((klass), GALEON_SPINNER_TYPE, GaleonSpinnerClass))
-#define IS_GALEON_SPINNER(obj)		(GTK_CHECK_TYPE ((obj), GALEON_SPINNER_TYPE))
-#define IS_GALEON_SPINNER_CLASS(klass)  (GTK_CHECK_CLASS_TYPE ((klass), GALEON_SPINNER_TYPE))
+#define GALEON_TYPE_SPINNER		(galeon_spinner_get_type ())
+#define GALEON_SPINNER(obj)		(GTK_CHECK_CAST ((obj), GALEON_TYPE_SPINNER, GaleonSpinner))
+#define GALEON_SPINNER_CLASS(klass)	(GTK_CHECK_CLASS_CAST ((klass), GALEON_TYPE_SPINNER, GaleonSpinnerClass))
+#define GALEON_IS_SPINNER(obj)		(GTK_CHECK_TYPE ((obj), GALEON_TYPE_SPINNER))
+#define GALEON_IS_SPINNER_CLASS(klass)  (GTK_CHECK_CLASS_TYPE ((klass), GALEON_TYPE_SPINNER))
 
 typedef struct GaleonSpinner GaleonSpinner;
 typedef struct GaleonSpinnerClass GaleonSpinnerClass;
